@@ -55,13 +55,8 @@ grl_range_value_new (GValue *min, GValue *max)
 void
 grl_range_value_free (GrlRangeValue *range)
 {
-  if (range->min) {
-    grl_g_value_free (range->min);
-  }
-
-  if (range->max) {
-    grl_g_value_free (range->max);
-  }
+  g_clear_pointer (&range->min, grl_g_value_free);
+  g_clear_pointer (&range->max, grl_g_value_free);
 
   g_slice_free (GrlRangeValue, range);
 }
