@@ -31,7 +31,7 @@
 /* Simple iteration to see that max and mix set in GrlOperationOptions is being
  * respected. The values cannot be outside bounderies of what is registered for
  * that metadata-key, e.g: GRL_METADATA_KEY_ORIENTATION has min: 0, max: 359 so
- * negative numbers or >=360 are not allowed */
+ * negative numbers or >=360 or max < min are not allowed */
 static void
 range_filters_max_min_int(void)
 {
@@ -42,9 +42,11 @@ range_filters_max_min_int(void)
     gint min_test;
     gint max_test;
     gboolean result_registered;
+    gboolean expected_ret;
   } int_keys[] = {
-    { GRL_METADATA_KEY_ORIENTATION, 0, 359, 90, 180, FALSE },
-    { GRL_METADATA_KEY_ORIENTATION, 0, 359, -1, 999, TRUE }
+    { GRL_METADATA_KEY_ORIENTATION, 0, 359, 90, 180, FALSE, TRUE  },
+    { GRL_METADATA_KEY_ORIENTATION, 0, 359, -1, 999, TRUE,  TRUE  },
+    { GRL_METADATA_KEY_ORIENTATION, 0, 359, 180, 90, FALSE, FALSE }
   };
 
   gint i;
@@ -59,15 +61,18 @@ range_filters_max_min_int(void)
                                                       int_keys[i].min_test,
                                                       int_keys[i].max_test,
                                                       NULL);
-    g_assert_true(ret);
-    grl_operation_options_get_key_range_filter (options, GRL_METADATA_KEY_ORIENTATION, &min, &max);
+    g_assert_cmpint(ret, ==, int_keys[i].expected_ret);
 
-    if (int_keys[i].result_registered) {
-      g_assert_cmpint(g_value_get_int (min), ==, int_keys[i].min_registered);
-      g_assert_cmpint(g_value_get_int (max), ==, int_keys[i].max_registered);
-    } else {
-      g_assert_cmpint(g_value_get_int (min), ==, int_keys[i].min_test);
-      g_assert_cmpint(g_value_get_int (max), ==, int_keys[i].max_test);
+    if (ret) {
+      grl_operation_options_get_key_range_filter (options, GRL_METADATA_KEY_ORIENTATION, &min, &max);
+
+      if (int_keys[i].result_registered) {
+        g_assert_cmpint(g_value_get_int (min), ==, int_keys[i].min_registered);
+        g_assert_cmpint(g_value_get_int (max), ==, int_keys[i].max_registered);
+      } else {
+        g_assert_cmpint(g_value_get_int (min), ==, int_keys[i].min_test);
+        g_assert_cmpint(g_value_get_int (max), ==, int_keys[i].max_test);
+      }
     }
   }
 }
